@@ -22,7 +22,7 @@ class Reformat:
     def __init__(self):
         self.log = Logger("reformat")
 
-        self.data_dir = os.path.expanduser(os.environ.get('DATA_DIR','data'))
+        self.data_dir = os.path.expanduser(os.environ.get('DATA_DIR','../dragg/data'))
         self.outputs_dir = os.path.expanduser(os.environ.get('OUTPUT_DIR','outputs'))
         if not os.path.isdir(self.outputs_dir):
             self.log.logger.error("No outputs directory found.")
